@@ -9,7 +9,7 @@ from clifold.commands.clifold_project import create
 
 def __version__():
     """return package version"""
-    return "0.2.4"
+    return "0.2.8"
 
 
 def cli():
@@ -50,12 +50,10 @@ def cli():
     pkg = args.pkg
     init = args.init
 
-    ppath = create(pname)
-    git_return = git_init(git, ppath)
-    pkg_return = pip(pkg, ppath, pname)
-    init_return = py_init(init, ppath, pname)
-
-    return ppath, git_return, pkg_return, init_return
+    ppath, root = create(pname)
+    git_init(git, ppath)
+    pip(pkg, root, pname)
+    py_init(init, ppath, pname)
 
 
 if __name__ == "__main__":
